@@ -82,6 +82,7 @@ static gchar *contributors[] = {
 	"Peter Fales",
 	"Joaquim Fellmann",
 	"Jens Finke",
+	"Mark Finlay",
 	"Dave Finton",
 	"Milon Firikis",
 	"John Fleck",
@@ -207,6 +208,7 @@ static gchar *contributors[] = {
 	"Karl Nelson",
 	"Elijah Newren",
 	"Christian Neumair",
+	"Mike Newman",
 	"Asger Alstrup Nielsen",
 	"Seth Nickell",
 	"Eric Nielson",
@@ -231,6 +233,7 @@ static gchar *contributors[] = {
 	"Joe Pfeiffer",
 	"Ben Pierce",
 	"Chris Pinkham",
+	"Hasbullah Bin Pit"
 	"Germ\xc3\xa1n Poo-Caama\xc3\xb1o",
 	"Dick Porter",
 	"Tero Pulkkinen",
@@ -253,7 +256,7 @@ static gchar *contributors[] = {
 	"S\xc3\xb8ren Sandmann",
 	"Pablo Saratxaga",
 	/* Kazuhiro Sasayama: */
-	"\xe7\xac\xb9 \xe5\xb1\xb1 \xe5\x92\x82 \xe5\xae\x8f",
+	"\xe7\xac\xb9 \xe5\xb1\xb1 \xe5\x92\x8c \xe5\xae\x8f",
 	"Carsten Schaar",
 	"Christian Schaller",
 	"Wayne Schuller",
